/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 03088
 |           ALCOHOL AND DRUG SERVICES STUDY (ADSS), 1996-1999:
 |                            [UNITED STATES]
 |                       (DATASET 0012: COST STUDY)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\03088-0012-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE factype   1='(1) HOSPITAL INPATIENT' 2='(2) RESIDENTIAL'
                  3='(3) OUTPATIENT METHADONE' 4='(4) OUTPATIENT NON-METHADONE' ;
  VALUE ownship   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PRIVATE, FOR-PROFIT' 2='(2) PRIVATE, NON-PROFIT' 3='(3) PUBLIC' ;
  VALUE multiple  0='(0) SINGLE MODALITY' 1='(1) MULTIPLE MODALITY' ;
  VALUE study     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' 0='(0) MAIN STUDY'
                  1='(1) INCENTIVE STUDY' ;
  VALUE nq3fffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq3fffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE oadmit    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE nqa       -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sqa       -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE big_n     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE big_n2ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE nqd       -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE nqd2ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sqd       -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nql       -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sql       -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nqb       -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sqb       -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq55ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq55ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE sq52ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nqi       -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sqi       -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nqg1ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sqg1ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nqg2ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sqg2ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nqg3ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sqg3ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nqg4ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sqg4ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nqg5ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sqg5ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nqgs      -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sqgs      -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE ngrphrs   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sgrphrs   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47a1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47a1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47b1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47b1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47c1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47c1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47d1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47d1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47e1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47e1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47f1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47f1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47g1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47g1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47h1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47h1ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49a     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49a     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49b     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49b     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49c     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49c     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49d     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49d     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49e     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49e     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49f     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49f     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49g     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49g     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49h     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49h     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47a4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47a4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47b4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47b4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47c4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47c4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47d4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47d4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47e4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47e4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47f4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47f4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47g4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47g4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47h4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47h4ff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47a23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47a23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47b23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47b23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47c23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47c23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47d23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47d23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47e23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47e23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47f23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47f23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47g23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47g23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47h23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47h23f  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49pa    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49pa    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49pb    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49pb    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49pc    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49pc    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49pd    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49pd    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49pe    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49pe    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49pf    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49pf    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49pg    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49pg    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq49ph    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq49ph    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47a4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47a4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47b4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47b4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47c4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47c4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47d4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47d4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47e4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47e4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47f4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47f4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47g4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47g4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq47h4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq47h4r   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nq50ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sq50ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE snb12fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nc21ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE snc21fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nc22ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE snc22fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nc3fffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sc3fffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nd14ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sd14ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE sd7fffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nd15a     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sd15a     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nd15ap    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sd15ap    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nd15a_d   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE nd15a_p   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE nd15b     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sd15b     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nd15bp    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sd15bp    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nd15b_d   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE nd15b_p   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE nd15c     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sd15c     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nd15cp    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sd15cp    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nd15c_d   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE nd15c_p   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE nd15d     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sd15d     -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nd15dp    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE sd15dp    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING'
                  1='(1) PROVIDER ORIGINAL' 2='(2) PROVIDER DOCUMENTATION'
                  3='(3) PROVIDER REVISED' 4='(4) INTERNAL ESTIMATE'
                  5='(5) EXTERNAL ESTIMATE' ;
  VALUE nd15d_d   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE nd15d_p   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v1k17fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v1k20fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v1k23fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n1c26fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n1g26fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v1k26fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n1c27fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n1g27fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v1k27fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n1c33fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n1g33fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v1k33fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n1c34fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n1g34fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v1k34fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n1c35fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n1g35fff  -99='(-99) INAPPLICABLE' ;
  VALUE v1k35fff  -99='(-99) INAPPLICABLE' ;
  VALUE v1c37fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v1c38fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v2f9ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v2f12fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE u2b22fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE u2d22fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v2f22fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE u2b23fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE u2d23fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE u2b25fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE u2d25fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v2f25fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE u2b26fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE u2d26fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE u2b28fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE u2b29fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE u2b30fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE u2b31fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n12fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n13fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n14fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n15fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n16fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n17fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n18fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n19fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n23fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n24fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n25fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n26fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n27fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n28fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n29fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n30fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3b32fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n32fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n33fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3n34fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE p3n38fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3j40fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE p3n40fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3j42fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE p3n42fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3j44fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE p3n44fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n3j46fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n7ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE p3n46fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4b8ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4f8ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4b9ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4f9ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4j9ffff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4j12fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n12fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n17fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n18fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n19fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n20fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n21fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n22fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4f24fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4j24fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4b27fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n27fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n30fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n31fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n32fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4j36fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n36fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n38fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n4n42fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v5f28fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v5f30fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v5f32fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n5d36fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE v5f36fff  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE abvisit   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE trt_dur   -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE abalos    -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE abalossd  -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE n         -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
  VALUE se        -99='(-99) INAPPLICABLE' -98='(-98) BLANK/MISSING' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=3528;
INPUT
        CASEID 1-8              FACID 9-16              FACTYPE 17-19
        OWNSHIP 20-22           MULTIPLE 23-25          STUDY 26-28
        F2FWA0 29-36 .2         CLWGT0 37-44 .2         PPWGT0 45-52 .2
        NQ3 53-56               SQ3 57-59               OADMIT 60-63
        NQA 64-67               SQA 68-70               BIG_N 71-74
        BIG_N2 75-78            NQD 79-82               NQD2 83-86
        SQD 87-89               NQL 90-97 .2            SQL 98-100
        NQB 101-103             SQB 104-106             NQ55 107-113
        SQ55 114-116            NQ52 117-123            SQ52 124-126
        NQI 127-133 .2          SQI 134-136             NQG1 137-142 .1
        SQG1 143-145            NQG2 146-151 .1         SQG2 152-154
        NQG3 155-160 .1         SQG3 161-163            NQG4 164-169 .1
        SQG4 170-172            NQG5 173-179 .2         SQG5 180-187
        NQGS 188-193 .2         SQGS 194-201            NGRPHRS 202-206 .2
        SGRPHRS 207-209         NQ47A1 210-212          SQ47A1 213-215
        NQ47B1 216-218          SQ47B1 219-221          NQ47C1 222-224
        SQ47C1 225-227          NQ47D1 228-230          SQ47D1 231-233
        NQ47E1 234-238 .1       SQ47E1 239-241          NQ47F1 242-244
        SQ47F1 245-247          NQ47G1 248-250          SQ47G1 251-253
        NQ47H1 254-258 .1       SQ47H1 259-261          NQ49A 262-268 .2
        SQ49A 269-271           NQ49B 272-278 .2        SQ49B 279-281
        NQ49C 282-288 .2        SQ49C 289-291           NQ49D 292-298 .2
        SQ49D 299-301           NQ49E 302-308 .2        SQ49E 309-311
        NQ49F 312-318 .2        SQ49F 319-321           NQ49G 322-328 .2
        SQ49G 329-331           NQ49H 332-338 .2        SQ49H 339-341
        NQ47A4 342-347 .1       SQ47A4 348-350          NQ47B4 351-356 .1
        SQ47B4 357-359          NQ47C4 360-365 .1       SQ47C4 366-368
        NQ47D4 369-374 .1       SQ47D4 375-377          NQ47E4 378-384 .2
        SQ47E4 385-387          NQ47F4 388-394 .2       SQ47F4 395-397
        NQ47G4 398-404 .2       SQ47G4 405-407          NQ47H4 408-414 .2
        SQ47H4 415-417          NQ47A23 418-420         SQ47A23 421-428
        NQ47B23 429-431         SQ47B23 432-434         NQ47C23 435-437
        SQ47C23 438-440         NQ47D23 441-443         SQ47D23 444-446
        NQ47E23 447-449         SQ47E23 450-452         NQ47F23 453-455
        SQ47F23 456-458         NQ47G23 459-461         SQ47G23 462-464
        NQ47H23 465-467         SQ47H23 468-470         NQ49PA 471-477 .2
        SQ49PA 478-480          NQ49PB 481-487 .2       SQ49PB 488-490
        NQ49PC 491-497 .2       SQ49PC 498-500          NQ49PD 501-507 .2
        SQ49PD 508-510          NQ49PE 511-517 .2       SQ49PE 518-520
        NQ49PF 521-527 .2       SQ49PF 528-530          NQ49PG 531-537 .2
        SQ49PG 538-540          NQ49PH 541-547 .2       SQ49PH 548-550
        NQ47A4R 551-557 .2      SQ47A4R 558-560         NQ47B4R 561-567 .2
        SQ47B4R 568-570         NQ47C4R 571-577 .2      SQ47C4R 578-580
        NQ47D4R 581-587 .2      SQ47D4R 588-590         NQ47E4R 591-597 .2
        SQ47E4R 598-600         NQ47F4R 601-607 .2      SQ47F4R 608-610
        NQ47G4R 611-617 .2      SQ47G4R 618-620         NQ47H4R 621-627 .2
        SQ47H4R 628-630         NQ50 631-637 .4         SQ50 638-640
        NB12 641-644            SNB12 645-647           NC21 648-651
        SNC21 652-654           NC22 655-658            SNC22 659-661
        NC3 662-669 .2          SC3 670-672             ND14 673-679
        SD14 680-682            ND7 683-689             SD7 690-692
        ND15A 693-701 .1        SD15A 702-704           ND15AP 705-712 .3
        SD15AP 713-715          ND15A_D 716-722         ND15A_P 723-731 .4
        ND15B 732-737           SD15B 738-740           ND15BP 741-748 .3
        SD15BP 749-751          ND15B_D 752-760 .1      ND15B_P 761-768 .3
        ND15C 769-777 .1        SD15C 778-780           ND15CP 781-789 .4
        SD15CP 790-792          ND15C_D 793-800 .1      ND15C_P 801-809 .4
        ND15D 810-816           SD15D 817-819           ND15DP 820-828 .4
        SD15DP 829-831          ND15D_D 832-840 .1      ND15D_P 841-849 .4
        V1K14 850-854 .2        V1K17 855-862 .4        V1K20 863-870 .4
        V1K23 871-878 .4        N1C26 879-885           N1G26 886-892 .1
        V1K26 893-900 .4        N1C27 901-907           N1G27 908-914
        V1K27 915-922 .4        V1K28 923-927 .2        N1C33 928-936 .4
        N1G33 937-945 .4        V1K33 946-954 .4        N1C34 955-963 .4
        N1G34 964-972 .4        V1K34 973-981 .4        N1C35 982-990 .4
        N1G35 991-995 .2        V1K35 996-1000 .2       V1C37 1001-1008 .4
        V1G37 1009-1013 .2      V1C38 1014-1021 .4      V1G38 1022-1026 .2
        V2F9 1027-1034 .4       V2F12 1035-1042 .4      U2B22 1043-1051 .1
        U2D22 1052-1058         V2F22 1059-1066 .4      U2B23 1067-1075 .4
        U2D23 1076-1084 .4      U2B25 1085-1091 .1      U2D25 1092-1098
        V2F25 1099-1106 .4      U2B26 1107-1115 .4      U2D26 1116-1124 .4
        U2B28 1125-1131 .1      U2D28 1132-1139 .2      V2F28 1140-1144 .2
        U2B29 1145-1153 .4      U2D29 1154-1159 .2      U2B30 1160-1168 .4
        U2B31 1169-1174 .2      N3N12 1175-1181 .1      N3N13 1182-1188 .1
        N3N14 1189-1195 .1      N3N15 1196-1202 .1      N3N16 1203-1209 .1
        N3N17 1210-1216 .1      N3N18 1217-1223 .1      N3N19 1224-1230 .1
        N3N23 1231-1237 .1      N3N24 1238-1244 .1      N3N25 1245-1251 .1
        N3N26 1252-1258 .1      N3N27 1259-1265 .1      N3N28 1266-1272 .1
        N3N29 1273-1279 .1      N3N30 1280-1286 .1      N3B32 1287-1293 .2
        N3N32 1294-1300 .1      N3N33 1301-1307 .1      N3N34 1308-1314 .1
        P3N38 1315-1321 .4      N3J40 1322-1328 .1      P3N40 1329-1335 .4
        N3J42 1336-1342 .1      P3N42 1343-1349 .4      N3J44 1350-1356 .1
        P3N44 1357-1363 .4      N3J46 1364-1370 .1      N4N7 1371-1377 .1
        P3N46 1378-1384 .4      N4B8 1385-1392 .4       N4F8 1393-1399 .1
        N4B9 1400-1407 .4       N4F9 1408-1414 .1       N4J9 1415-1422 .4
        N4J12 1423-1431 .4      N4N12 1432-1438 .1      N4N17 1439-1444 .2
        N4N18 1445-1449 .2      N4N19 1450-1455 .2      N4N20 1456-1462 .3
        N4N21 1463-1469 .4      N4N22 1470-1477 .4      N4F24 1478-1485 .4
        N4J24 1486-1494 .4      N4B27 1495-1503 .4      N4N27 1504-1510 .1
        N4N30 1511-1517 .1      N4N31 1518-1524 .4      N4N32 1525-1531 .4
        N4J36 1532-1538 .1      N4N36 1539-1545 .1      N4N38 1546-1552 .1
        N4N42 1553-1559 .1      V5B16 1560-1563 .2      V5B24 1564-1566 .2
        V5F28 1567-1574 .4      V5F30 1575-1582 .4      V5F32 1583-1590 .4
        N5D36 1591-1599 .4      V5F36 1600-1608 .4      ABVISIT 1609-1617 .4
        TRT_DUR 1618-1624       ABALOS 1625-1631 .1     ABALOSSD 1632-1640 .1
        N 1641-1643             SE 1644-1650 .1         F2FWA1 1651-1658 .2
        F2FWA2 1659-1666 .2     F2FWA3 1667-1674 .2     F2FWA4 1675-1682 .2
        F2FWA5 1683-1690 .2     F2FWA6 1691-1698 .2     F2FWA7 1699-1706 .2
        F2FWA8 1707-1714 .2     F2FWA9 1715-1722 .2     F2FWA10 1723-1730 .2
        F2FWA11 1731-1738 .2    F2FWA12 1739-1746 .2    F2FWA13 1747-1754 .2
        F2FWA14 1755-1762 .2    F2FWA15 1763-1770 .2    F2FWA16 1771-1778 .2
        F2FWA17 1779-1786 .2    F2FWA18 1787-1794 .2    F2FWA19 1795-1802 .2
        F2FWA20 1803-1810 .2    F2FWA21 1811-1818 .2    F2FWA22 1819-1826 .2
        F2FWA23 1827-1834 .2    F2FWA24 1835-1842 .2    F2FWA25 1843-1850 .2
        F2FWA26 1851-1858 .2    F2FWA27 1859-1866 .2    F2FWA28 1867-1874 .2
        F2FWA29 1875-1882 .2    F2FWA30 1883-1890 .2    F2FWA31 1891-1898 .2
        F2FWA32 1899-1906 .2    F2FWA33 1907-1914 .2    F2FWA34 1915-1922 .2
        F2FWA35 1923-1930 .2    F2FWA36 1931-1938 .2    F2FWA37 1939-1946 .2
        F2FWA38 1947-1954 .2    F2FWA39 1955-1962 .2    F2FWA40 1963-1970 .2
        F2FWA41 1971-1978 .2    F2FWA42 1979-1986 .2    F2FWA43 1987-1994 .2
        F2FWA44 1995-2002 .2    F2FWA45 2003-2010 .2    F2FWA46 2011-2018 .2
        F2FWA47 2019-2026 .2    F2FWA48 2027-2034 .2    F2FWA49 2035-2042 .2
        F2FWA50 2043-2050 .2    F2FWA51 2051-2058 .2    F2FWA52 2059-2066 .2
        F2FWA53 2067-2074 .2    F2FWA54 2075-2082 .2    F2FWA55 2083-2090 .2
        F2FWA56 2091-2098 .2    F2FWA57 2099-2106 .2    F2FWA58 2107-2114 .2
        F2FWA59 2115-2122 .2    F2FWA60 2123-2130 .2    F2FWA61 2131-2138 .2
        F2FWA62 2139-2146 .2    F2FWA63 2147-2154 .2    F2FWA64 2155-2162 .2
        F2FWA65 2163-2170 .2    F2FWA66 2171-2178 .2    F2FWA67 2179-2186 .2
        F2FWA68 2187-2194 .2    F2FWA69 2195-2202 .2    F2FWA70 2203-2210 .2
        F2FWA71 2211-2218 .2    F2FWA72 2219-2226 .2    F2FWA73 2227-2234 .2
        F2FWA74 2235-2242 .2    F2FWA75 2243-2250 .2    F2FWA76 2251-2258 .2
        F2FWA77 2259-2266 .2    F2FWA78 2267-2274 .2    CLWGT1 2275-2282 .2
        CLWGT2 2283-2290 .2     CLWGT3 2291-2298 .2     CLWGT4 2299-2306 .2
        CLWGT5 2307-2314 .2     CLWGT6 2315-2322 .2     CLWGT7 2323-2330 .2
        CLWGT8 2331-2338 .2     CLWGT9 2339-2346 .2     CLWGT10 2347-2354 .2
        CLWGT11 2355-2362 .2    CLWGT12 2363-2370 .2    CLWGT13 2371-2378 .2
        CLWGT14 2379-2386 .2    CLWGT15 2387-2394 .2    CLWGT16 2395-2402 .2
        CLWGT17 2403-2410 .2    CLWGT18 2411-2418 .2    CLWGT19 2419-2426 .2
        CLWGT20 2427-2434 .2    CLWGT21 2435-2442 .2    CLWGT22 2443-2450 .2
        CLWGT23 2451-2458 .2    CLWGT24 2459-2466 .2    CLWGT25 2467-2474 .2
        CLWGT26 2475-2482 .2    CLWGT27 2483-2490 .2    CLWGT28 2491-2498 .2
        CLWGT29 2499-2506 .2    CLWGT30 2507-2514 .2    CLWGT31 2515-2522 .2
        CLWGT32 2523-2530 .2    CLWGT33 2531-2538 .2    CLWGT34 2539-2546 .2
        CLWGT35 2547-2554 .2    CLWGT36 2555-2562 .2    CLWGT37 2563-2570 .2
        CLWGT38 2571-2578 .2    CLWGT39 2579-2586 .2    CLWGT40 2587-2594 .2
        CLWGT41 2595-2602 .2    CLWGT42 2603-2610 .2    CLWGT43 2611-2618 .2
        CLWGT44 2619-2626 .2    CLWGT45 2627-2634 .2    CLWGT46 2635-2642 .2
        CLWGT47 2643-2650 .2    CLWGT48 2651-2658 .2    CLWGT49 2659-2666 .2
        CLWGT50 2667-2674 .2    CLWGT51 2675-2682 .2    CLWGT52 2683-2690 .2
        CLWGT53 2691-2698 .2    CLWGT54 2699-2706 .2    CLWGT55 2707-2714 .2
        CLWGT56 2715-2722 .2    CLWGT57 2723-2730 .2    CLWGT58 2731-2738 .2
        CLWGT59 2739-2746 .2    CLWGT60 2747-2754 .2    CLWGT61 2755-2762 .2
        CLWGT62 2763-2770 .2    CLWGT63 2771-2778 .2    CLWGT64 2779-2786 .2
        CLWGT65 2787-2794 .2    CLWGT66 2795-2802 .2    CLWGT67 2803-2810 .2
        CLWGT68 2811-2818 .2    CLWGT69 2819-2826 .2    CLWGT70 2827-2834 .2
        CLWGT71 2835-2842 .2    CLWGT72 2843-2850 .2    CLWGT73 2851-2858 .2
        CLWGT74 2859-2866 .2    CLWGT75 2867-2874 .2    CLWGT76 2875-2882 .2
        CLWGT77 2883-2890 .2    CLWGT78 2891-2898 .2    PPWGT1 2899-2906 .2
        PPWGT2 2907-2914 .2     PPWGT3 2915-2922 .2     PPWGT4 2923-2930 .2
        PPWGT5 2931-2938 .2     PPWGT6 2939-2946 .2     PPWGT7 2947-2954 .2
        PPWGT8 2955-2962 .2     PPWGT9 2963-2970 .2     PPWGT10 2971-2978 .2
        PPWGT11 2979-2986 .2    PPWGT12 2987-2994 .2    PPWGT13 2995-3002 .2
        PPWGT14 3003-3010 .2    PPWGT15 3011-3018 .2    PPWGT16 3019-3026 .2
        PPWGT17 3027-3034 .2    PPWGT18 3035-3042 .2    PPWGT19 3043-3050 .2
        PPWGT20 3051-3058 .2    PPWGT21 3059-3066 .2    PPWGT22 3067-3074 .2
        PPWGT23 3075-3082 .2    PPWGT24 3083-3090 .2    PPWGT25 3091-3098 .2
        PPWGT26 3099-3106 .2    PPWGT27 3107-3114 .2    PPWGT28 3115-3122 .2
        PPWGT29 3123-3130 .2    PPWGT30 3131-3138 .2    PPWGT31 3139-3146 .2
        PPWGT32 3147-3154 .2    PPWGT33 3155-3162 .2    PPWGT34 3163-3170 .2
        PPWGT35 3171-3178 .2    PPWGT36 3179-3186 .2    PPWGT37 3187-3194 .2
        PPWGT38 3195-3202 .2    PPWGT39 3203-3210 .2    PPWGT40 3211-3218 .2
        PPWGT41 3219-3226 .2    PPWGT42 3227-3234 .2    PPWGT43 3235-3242 .2
        PPWGT44 3243-3250 .2    PPWGT45 3251-3258 .2    PPWGT46 3259-3266 .2
        PPWGT47 3267-3274 .2    PPWGT48 3275-3282 .2    PPWGT49 3283-3290 .2
        PPWGT50 3291-3298 .2    PPWGT51 3299-3306 .2    PPWGT52 3307-3314 .2
        PPWGT53 3315-3322 .2    PPWGT54 3323-3330 .2    PPWGT55 3331-3338 .2
        PPWGT56 3339-3346 .2    PPWGT57 3347-3354 .2    PPWGT58 3355-3362 .2
        PPWGT59 3363-3370 .2    PPWGT60 3371-3378 .2    PPWGT61 3379-3386 .2
        PPWGT62 3387-3394 .2    PPWGT63 3395-3402 .2    PPWGT64 3403-3410 .2
        PPWGT65 3411-3418 .2    PPWGT66 3419-3426 .2    PPWGT67 3427-3434 .2
        PPWGT68 3435-3442 .2    PPWGT69 3443-3450 .2    PPWGT70 3451-3458 .2
        PPWGT71 3459-3466 .2    PPWGT72 3467-3474 .2    PPWGT73 3475-3482 .2
        PPWGT74 3483-3490 .2    PPWGT75 3491-3498 .2    PPWGT76 3499-3506 .2
        PPWGT77 3507-3514 .2    PPWGT78 3515-3522 .2    VST_PSU 3523-3525
        VUN_PSU 3526-3528       ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   FACID   = '1. FACILITY ID'
   FACTYPE = '4. TYPE OF CARE'
   OWNSHIP = '5. OWNERSHIP'
   MULTIPLE= '6. MULTIPLE MODALITY FLAG'
   STUDY   = '7. STUDY FLAG'
   F2FWA0  = '9. FINAL PHASE II FACILITY WEIGHT'
   CLWGT0  = '10. PHASE II-CLIENT ANALYSIS WEIGHT'
   PPWGT0  = '11. PHASE II-PREVALENCE ANALYSIS WEIGHT'
   NQ3     = '12. PHASE II-POINT PREVALENCE'
   SQ3     = '13. PHASE II-POINT PREVALENCE SOURCE'
   OADMIT  = '14. UNADJUSTED PHASE II ADMISSIONS'
   NQA     = '15. PHASE II-CLIENT ADMISSIONS'
   SQA     = '16. PHASE II-CLIENT ADMISSIONS SOURCE'
   BIG_N   = '17. UNADJUSTED 6-MONTH DISCHARGE COUNTS'
   BIG_N2  = '18. UNADJUSTED 12-MONTH DISCHARGES CALC'
   NQD     = '19. PHASE II-CLIENT DISCHARGES - 6 MONTH'
   NQD2    = '20. PHASE II-CLIENT DISCHARGES - 12 MON'
   SQD     = '21. PHASE II-CLIENT DISCHARGES SOURCE'
   NQL     = '22. PHASE II-AVERAGE LENGTH OF STAY -DAYS'
   SQL     = '23. PHASE II-ALOS (DAYS) SOURCE'
   NQB     = '24. PHASE II-RES BED CAPACITY'
   SQB     = '25. PHASE II-RES BED CAPACITY SOURCE'
   NQ55    = '26. PHASE II-TOTAL COSTS'
   SQ55    = '27. PHASE II-TOTAL COSTS SOURCE'
   NQ52    = '28. POST-AUDIT PHASE II-TOTAL REVENUES'
   SQ52    = '29. PHASE II-TOTAL REVENUES SOURCE'
   NQI     = '30. PHASE II-IND COUN SESS PER CL PER WK'
   SQI     = '31. PHASE II-NUMBER OF IND COUNS SESS SC'
   NQG1    = '32. PHASE II-MEAN CLIENTS IN THERAPY GRP'
   SQG1    = '33. PHASE II-MEAN CLTS IN THERAPY GRP SC'
   NQG2    = '34. PHASE II-MEAN CLIENTS IN ED GRP'
   SQG2    = '35. PHASE II-MEAN CLIENTS IN ED GRP SC'
   NQG3    = '36. PHASE II-MEAN CLIENTS IN SELF-HELP GR'
   SQG3    = '37. PHASE II-MEAN CLTS SELF-HELP GRP SC'
   NQG4    = '38. PHASE II-MEAN CLIENTS IN COMMUNITY GR'
   SQG4    = '39. PHII-MEAN CLIENTS IN COMM GRP SOURCE'
   NQG5    = '40. PHASE II-MEAN CLIENTS IN OTHER GRP'
   SQG5    = '41. PHASE II-MEAN CLNTS IN OTHER GRP SC'
   NQGS    = '42. PHII-GRP COUN SESS PER CLT PER WEEK'
   SQGS    = '43. PHII-GRP COUN SESS PER CLT PER WK SC'
   NGRPHRS = '44. LENGTH OF GROUP SESSION (HOURS)'
   SGRPHRS = '45. LENGTH OF GROUP SESSION SOURCE'
   NQ47A1  = '46. PHASE II-NUMBER OF FTE PHYSICIANS'
   SQ47A1  = '47. PHII-NUMBER OF FTE PHYSICIANS - SC'
   NQ47B1  = '48. PHASE II-NUMBER OF FTE NURSES'
   SQ47B1  = '49. PHII-NUMBER OF FTE NURSES SOURCE'
   NQ47C1  = '50. PHASE II-NUMBER OF FTE OTHER MEDICAL'
   SQ47C1  = '51. PHII-NUMBER OF FTE OTHER MED SOURCE'
   NQ47D1  = '52. PHASE II-NUMBER OF FTE PSYCHOLOGISTS'
   SQ47D1  = '53. PHII-NUMBER OF FTE PSYCHOLOGISTS SC'
   NQ47E1  = '54. PHASE II-NUMBER OF FTE MA COUSELORS'
   SQ47E1  = '55. PHASE II-NUMBER OF FTE MA COUNSLRS SC'
   NQ47F1  = '56. PHASE II-NUMBER OF FTE BA COUNSELORS'
   SQ47F1  = '57. PHASE II-NUMBER OF FTE BA COUNSLRS SC'
   NQ47G1  = '58. PHASE II-NUMBER OF FTE NDG COUNSELORS'
   SQ47G1  = '59. PHII-NUMBER OF FTE NDG COUNSELORS SC'
   NQ47H1  = '60. PHASE II-NUMBER OF FTE ADMIN'
   SQ47H1  = '61. PHASE II-NUMBER OF FTE ADMIN - SOURCE'
   NQ49A   = '62. PHASE II-HOURLY RATE FTE PHYSICIANS'
   SQ49A   = '63. PHII-HOURLY RATE FTE PHYSICIANS SC'
   NQ49B   = '64. PHASE II-HOURLY RATE FTE NURSES'
   SQ49B   = '65. PHASE II-HOURLY RATE FTE NURSES SOURC'
   NQ49C   = '66. PHASE II-HOURLY RATE FTE OTHER MED'
   SQ49C   = '67. PHASE II-HOURLY RATE FTE OTHER MED SO'
   NQ49D   = '68. PHASE II-HOURLY RATE FTE PSYCHOLOGIST'
   SQ49D   = '69. PHII-HOURLY RATE FTE PSYCHOLOGIST SC'
   NQ49E   = '70. PHASE II-HOURLY RATE FTE MA COUNSELOR'
   SQ49E   = '71. PHASE II-HRLY RATE FTE MA COUNLR SC'
   NQ49F   = '72. PHASE II-HOURLY RATE FTE BA COUNSLR'
   SQ49F   = '73. PHASE II-HOURLY RATE FTE BA COUNLR SC'
   NQ49G   = '74. PHASE II-HOURLY RATE FTE NOD COUNLR'
   SQ49G   = '75. PHII-HRLY RATE FTE NDG COUNLR SOURCE'
   NQ49H   = '76. PHASE II-HOURLY RATE FTE ADMIN'
   SQ49H   = '77. PHASE II-HOURLY RATE FTE ADMIN SC'
   NQ47A4  = '78. PHASE II-HOURS/WEEK FTE PHYSICIANS'
   SQ47A4  = '79. PHII-HOURS/WEEK FTE PHYSICIANS SC'
   NQ47B4  = '80. PHASE II-HOURS/WEEK FTE NURSES'
   SQ47B4  = '81. PHASE II-HOURS/WEEK FTE NURSES SOURCE'
   NQ47C4  = '82. PHASE II-HOURS/WEEK FTE OTHER MED'
   SQ47C4  = '83. PHASE II-HOURS/WEEK FTE OTHER MED SC'
   NQ47D4  = '84. PHII-HOUR/WEEK FTE PSYCHOLOGISTS'
   SQ47D4  = '85. PHII-HOURS/WEEK FTE PSYCHOLOGISTS SC'
   NQ47E4  = '86. PHASE II-HOURS/WEEK FTE MA COUNLR'
   SQ47E4  = '87. PHASE II-HOURS/WEEK FTE MA COUNLR SOU'
   NQ47F4  = '88. PHASE II-HOURS/WEEK FTE BA COUNLR'
   SQ47F4  = '89. PHASE II-HOURS/WEEK FTE BA COUNLR SOU'
   NQ47G4  = '90. PHASE II-HOURS/WEEK FTE NDG COUNLR'
   SQ47G4  = '91. PHII-HRS/WEEK FTE NDG COUNLR SOURCE'
   NQ47H4  = '92. PHASE II-HOURS/WEEK FTE ADMIN'
   SQ47H4  = '93. PHASE II-HOURS/WEEK FTE ADMIN SOURCE'
   NQ47A23 = '94. PHASE II-PTE PHYSICIANS'
   SQ47A23 = '95. PHASE II-PTE PHYSICIANS SOURCE'
   NQ47B23 = '96. PHASE II-PTE NURSES'
   SQ47B23 = '97. PHASE II-PTE NURSES SOURCE'
   NQ47C23 = '98. PHASE II-PTE OTHER MEDICAL'
   SQ47C23 = '99. PHASE II-PTE OTHER MED SOURCE'
   NQ47D23 = '100. PHASE II-PTE PSYCHOLOGISTS'
   SQ47D23 = '101. PHASE II-PTE PSYCHOLOGISTS SOURCE'
   NQ47E23 = '102. PHASE II-PTE MA COUNLR'
   SQ47E23 = '103. PHASE II-PTE MA COUNLR SOURCE'
   NQ47F23 = '104. PHASE II-PTE BA COUNLR'
   SQ47F23 = '105. PHASE II-PTE BA COUNLR SOURCE'
   NQ47G23 = '106. PHASE II-PTE NDG COUNLR'
   SQ47G23 = '107. PHASE II-PTE NDGR COUNLR SOURCE'
   NQ47H23 = '108. PHASE II-PTE ADMIN'
   SQ47H23 = '109. PHASE II-PTE ADMIN SOURCE'
   NQ49PA  = '110. PHASE II-HOURLY RATE PTE PHYSICIANS'
   SQ49PA  = '111. PHII-HRLY RATE PTE PHYSICIAN SOURCE'
   NQ49PB  = '112. PHASE II-HOURLY RATE PTE NURSES'
   SQ49PB  = '113. PHASE II-HRLY RATE PTE NURSES SOURCE'
   NQ49PC  = '114. PHASE II-HOURLY RATE PTE OTHER MED'
   SQ49PC  = '115. PHII-HRLY RATE PTE OTHER MED SOURCE'
   NQ49PD  = '116. PHASE II-HRLY RATE PTE PSYCHOLOGISTS'
   SQ49PD  = '117. PHII-HRLY RATE PTE PSYCHOLOGISTS SC'
   NQ49PE  = '118. PHASE II-HOURLY RATE PTE MA COUNLR'
   SQ49PE  = '119. PHASE II-HRLY RATE PTE MA COUNLR SC'
   NQ49PF  = '120. PHASE II-HOURLY RATE PTE BA COUNLR'
   SQ49PF  = '121. PHASE II-HRLY RATE PTE BA COUNLR SC'
   NQ49PG  = '122. PHASE II-HOURLY RATE PTE NDG COUNLR'
   SQ49PG  = '123. PHII-HRLY RATE PTE NDG COUNLR SC'
   NQ49PH  = '124. PHASE II-HOURLY RATE PTE ADMIN'
   SQ49PH  = '125. PHASE II-HOURLY RATE PTE ADMIN SC'
   NQ47A4R = '126. PHASE II-HOURS/WEEK PTE PHYSICIANS'
   SQ47A4R = '127. PHII-HOURS/WEEK PTE PHYSICIANS SC'
   NQ47B4R = '128. PHASE II-HOURS/WEEK PTE NURSES'
   SQ47B4R = '129. PHASE II-HOURS/WEEK FTE NURSES SC'
   NQ47C4R = '130. PHASE II-HOURS/WEEK PTE OTHER MED'
   SQ47C4R = '131. PHASE II-HOURS/WEEK PTE OTHER MED SC'
   NQ47D4R = '132. PHII-HOURS/WEEK PTE PSYCHOLOGISTS'
   SQ47D4R = '133. PHII-HOURS/WEEK PTE PSYCHOLOGISTS SC'
   NQ47E4R = '134. PHASE II-HOURS/WEEK PTE MA COUNLR'
   SQ47E4R = '135. PHASE II-HOURS/WEEK PTE MA COUNLR SC'
   NQ47F4R = '136. PHASE II-HOURS/WEEK PTE BA COUNLR'
   SQ47F4R = '137. PHASE II-HOURS/WEEK PTE BA COUNLR SC'
   NQ47G4R = '138. PHASE II-HOURS/WEEK PTE NDG COUNLR'
   SQ47G4R = '139. PHII-HOURS/WEEK PTE NDG COUNLR SC'
   NQ47H4R = '140. PHASE II-HOURS/WEEK PTE ADMIN'
   SQ47H4R = '141. PHASE II-HOURS/WEEK PTE ADMIN SOURCE'
   NQ50    = '142. PHASE II-FRINGE BENEFIT RATE'
   SQ50    = '143. PHASE II-FRINGE BENEFIT RATE SOURCE'
   NB12    = '144. POST-AUDIT PHASE I-POINT PREVALENCE'
   SNB12   = '145. PHASEI-POINT PREVALENCE SOURCE'
   NC21    = '146. PHASEI-ADMISSIONS'
   SNC21   = '147. PHASEI-ADMISSIONS SOURCE'
   NC22    = '148. PHASEI-DISCHARGES'
   SNC22   = '149. PHASEI-DISCHARGES SOURCE'
   NC3     = '150. PHASEI-AVERAGE LENGTH OF STAY'
   SC3     = '151. PHASEI-AVERAGE LENGTH OF STAY SOURC'
   ND14    = '152. PHASEI-TOTAL COSTS'
   SD14    = '153. PHASEI-TOTAL COSTS SOURCE'
   ND7     = '154. POST-AUDIT PHASE I-TOTAL REVENUES'
   SD7     = '155. PHASEI-TOTAL REVENUES SOURCE'
   ND15A   = '156. PHASEI-RAW COSTS FOR FTE'
   SD15A   = '157. PHASEI-RAW COSTS FOR FTE SOURCE'
   ND15AP  = '158. PHASEI-RAW COSTS PROP FOR FTE'
   SD15AP  = '159. PHASEI-RAW COSTS PROP FOR FTE SOUR'
   ND15A_D = '160. PHASEI-COSTS CALC FOR FTE'
   ND15A_P = '161. PHASEI-COSTS PROP CALC FOR FTE'
   ND15B   = '162. PHASEI- RAW COSTS FOR OTH PERSNL'
   SD15B   = '163. PHASEI-RAW COSTS FOR OTH PERSNNL SC'
   ND15BP  = '164. PHI-RAW COSTS PROP FOR OTHER PERSL'
   SD15BP  = '165. PHI-RAW COSTS PROP FOR OTH PERSL SC'
   ND15B_D = '166. PHASEI-COST CALC FOR OTHER PERSONNE'
   ND15B_P = '167. PHI-COST PROP CALC FOR OTHER PERSL'
   ND15C   = '168. PHASEI-RAW COSTS FOR NON-PER'
   SD15C   = '169. PHASEI-RAW COSTS FOR NON-PERSL SC'
   ND15CP  = '170. PHASEI-RAW COSTS PROP FOR NON-PERS'
   SD15CP  = '171. PHASEI-RAW COSTS  PROP FOR NON-PER'
   ND15C_D = '172. PHASEI-COSTS CALC FOR NON-PER'
   ND15C_P = '173. PHASEI-COSTS PROP CALC FOR NON-PER'
   ND15D   = '174. PHASEI-RAW TOTAL COSTS'
   SD15D   = '175. PHASEI-RAW TOTAL COSTS SOURCE'
   ND15DP  = '176. PHASEI-RAW TOTAL COSTS PROP'
   SD15DP  = '177. PHASEI-RAW TOTAL COSTS PROP SOURCE'
   ND15D_D = '178. PHASEI-RAW TOTAL COSTS CALC'
   ND15D_P = '179. PHASEI-RAW TOTAL COSTS PROP'
   V1K14   = '180. DIFFERENCE POINT PREVALENCE'
   V1K17   = '181. DIFFERENCE ADMISSIONS'
   V1K20   = '182. DIFFERENCE DISCHARGES'
   V1K23   = '183. DIFFERENCE AVERAGE LENGTH OF STAY'
   N1C26   = '184. PHASE II ADMISSION DERIVATIVE'
   N1G26   = '185. PHASEI ADMISSION DERIVATIVE'
   V1K26   = '186. DIFFERENCE ADMISSION DERIVATIVE'
   N1C27   = '187. PHASE II DISCHARGE DERIVATIVE'
   N1G27   = '188. PHASEI DISCHARGE DERIVATIVE'
   V1K27   = '189. DIFFERENCE DISCHARGE DERIVATIVE'
   V1K28   = '190. DIFFERENCE POINT PREVALENCE'
   N1C33   = '191. PHASE II- ADMISSION BASED OCCUPANCY'
   N1G33   = '192. PHASEI-ADMISSION BASED OCCUPANCY'
   V1K33   = '193. DIFFERENCE AD BASED OCCUPANCY'
   N1C34   = '194. PHASE II- DISCHARGE BASED OCCUPANCY'
   N1G34   = '195. PHASEI- DISCHARGE BASED OCCUPANCY'
   V1K34   = '196. DIFFERENCE DC BASED OCCUPANCY'
   N1C35   = '197. PHASE II- POINT PREV BASED OCCUPANCY'
   N1G35   = '198. PHASEI- POINT PREV BASED OCCUPANCY'
   V1K35   = '199. DIFFERENCE PP BASED OCCUPANCY'
   V1C37   = '200. DIFFERENCE PHASE II AD AND PP'
   V1G37   = '201. DIFFERENCE PHASE I AD AND PP'
   V1C38   = '202. DIFFERENCE PHASE II DC AND PP'
   V1G38   = '203. DIFFERENCE PHASE I DC AND PP'
   V2F9    = '204. DIFFERENCE TOTAL COSTS'
   V2F12   = '205. DIFFERENCE TOTAL REVENUES'
   U2B22   = '206. PHASE II-COST PER EPISODE FROM AD'
   U2D22   = '207. PHASEI-COST PER EPISODE FROM AD'
   V2F22   = '208. DIFFERENCE COST PER EPISODE FROM AD'
   U2B23   = '209. PHII-COST PER PATIENT DAY FROM AD'
   U2D23   = '210. PHASEI-COST PER PATIENT DAY FROM AD'
   U2B25   = '211. PHASE II-COST PER EPISODE FROM DC'
   U2D25   = '212. PHASEI-COST PER EPISODE FROM DC'
   V2F25   = '213. DIFFERENCE COST PER EPISODE FROM DC'
   U2B26   = '214. PHII-COST PER PATIENT DAY FROM DC'
   U2D26   = '215. PHASEI-COST PER PATIENT DAY FROM DC'
   U2B28   = '216. PHASE II-COST PER EPISODE FROM PP'
   U2D28   = '217. PHASEI-COST PER EPISODE FROM PP'
   V2F28   = '218. DIFFERENCE COST PER EPISODE FROM PP'
   U2B29   = '219. PHII-COST PER PATIENT DAY FROM PP'
   U2D29   = '220. PHASEI-COST PER PATIENT DAY FROM PP'
   U2B30   = '221. COST PER REPORTED VISIT'
   U2B31   = '222. COST PER DOCUMENTED VISIT'
   N3N12   = '223. PHII ANNUAL SALARY FT PHYSICIANS'
   N3N13   = '224. PHII ANNUAL SALARY FT NURSES'
   N3N14   = '225. PHII ANNUAL SALARY FT OTHER MEDICAL'
   N3N15   = '226. PHII ANNUAL SALARY FT PSYCHOLOGISTS'
   N3N16   = '227. PHII ANNUAL SALARY FT MA COUN'
   N3N17   = '228. PHII ANNUAL SALARY FT BA COUN'
   N3N18   = '229. PHII ANNUAL SALARY FT NDG COUN'
   N3N19   = '230. PHII ANNUAL SALARY FT ADMINSTRATORS'
   N3N23   = '231. PHII ANNUAL SALARY PT PHYSICIANS'
   N3N24   = '232. PHII ANNUAL SALARY PT NURSES'
   N3N25   = '233. PHII ANNUAL SALARY PT OTHER MEDICAL'
   N3N26   = '234. PHII ANNUAL SALARY PT PSYCHOLOGISTS'
   N3N27   = '235. PHII ANNUAL SALARY PT MA COUN'
   N3N28   = '236. PHII ANNUAL SALARY PT BA COUN'
   N3N29   = '237. PHII ANNUAL SALARY PT NDG COUN'
   N3N30   = '238. PHII ANNUAL SALARY PT ADMINSTRATORS'
   N3B32   = '239. PHII TOTAL NUMBER OF EMP FT AND PT'
   N3N32   = '240. PHII TOTAL ANNUAL SALARY COSTS'
   N3N33   = '241. PHII TOTAL COSTS OF FRINGE BENEFITS'
   N3N34   = '242. PHII TOTAL COSTS OF PERSONNEL'
   P3N38   = '243. PHII PROP OF PERSNEL COSTS OF TOTAL'
   N3J40   = '244. PHII SUM COUNSELING PERSONNEL COSTS'
   P3N40   = '245. PHII PROP COUN PER COSTS OF TOTAL P'
   N3J42   = '246. PHII SUM MEDICAL PERSONNEL COSTS'
   P3N42   = '247. PHII PROP MED PER COSTS OF TOTAL PE'
   N3J44   = '248. PHII SUM ADMIN PERSONNEL COSTS'
   P3N44   = '249. PHII PROP ADMIN PER COSTS OF TOTAL'
   N3J46   = '250. PHII SUM OF DIRECT PERSONNEL COSTS'
   N4N7    = '251. PHII SALARIES TOTAL'
   P3N46   = '252. PHII PROP DIRECT PER COSTS TO TOTAL'
   N4B8    = '253. PHII TOTAL FTE HOURS PROF STAFF'
   N4F8    = '254. PHII TOTAL FTE HRS PRO STAFF ANNUAL'
   N4B9    = '255. PHII TOTAL FTE HOURS COUNSELORS'
   N4F9    = '256. PHII TOTAL FTE HOURS COUNS ANNUALIZ'
   N4J9    = '257. PHII COUN PER COSTS PER ANNFTE HOUR'
   N4J12   = '258. PHII ALOS IN WEEKS'
   N4N12   = '259. PHII INDIVIDUAL COUNSEL HOURS PER W'
   N4N17   = '260. PHII WEIGHTED ATTENDANCE GT'
   N4N18   = '261. PHII WEIGHTED ATTENDANCE ED GROUP'
   N4N19   = '262. PHII WEIGHTED ATTENDANCE SELF-HELP'
   N4N20   = '263. PHII WEIGHTED ATTENDANCE COMM GP'
   N4N21   = '264. PHII WEIGHTED ATTENDANCE OTHER GP'
   N4N22   = '265. PHII WEIGHTED ATTENDANCE TOTAL GP'
   N4F24   = '266. PHII AVERAGE GROUP ATTENDANCE'
   N4J24   = '267. PHII NO. GROUPS PER COUNSELOR'
   N4B27   = '268. PHII NO. OF SESSIONS'
   N4N27   = '269. PHII ANNUALIZED GROUP COUNSELING HR'
   N4N30   = '270. PHII TOTAL ANNUAL COUNSELING HRS'
   N4N31   = '271. PHII PROP COU HRS OF COUNSELOR HRS'
   N4N32   = '272. PHII PROP COUL HRS OF PRO STAFF'
   N4J36   = '273. PHII TOTAL COST OF ANNUAL COUN HRS'
   N4N36   = '274. PHII PER ADMISSION COST ANNUAL COUN'
   N4N38   = '275. PHII PER ADMISSION COST FTE COUN HR'
   N4N42   = '276. PHII TOTAL GROUP CONTACT HOURS'
   V5B16   = '277. DIFFERENCE OF AD, PP, DC DIFFERENCE'
   V5B24   = '278. DIFF AVERAGE OF COSTS AND REV DIFF'
   V5F28   = '279. DIFFERENCE PHASE II AD AND DC'
   V5F30   = '280. DIFFERENCE PHASE II AD AND PP'
   V5F32   = '281. DIFFERENCE PHASE II DC AND PP'
   N5D36   = '282. PHI PROP OF PER COSTS TO TOTAL COST'
   V5F36   = '283. DIFFERENCE PERSONNEL COST TO TOTAL'
   ABVISIT = '284. MEAN ABSTRACT DOCUMENTED VISITS'
   TRT_DUR = '285. MEAN TXT DURATION FROM ABSTRACT FI'
   ABALOS  = '286. MEAN ABSTRACT  DOCUMENTED ALOS'
   ABALOSSD= '287. SD OF ABSTRACT DOCUMENTED  ALOS'
   N       = '288. NUMBER OF ABSTACTS'
   SE      = '289. SE  OF MEAN ABST FILE DOCUMENTED AL'
   F2FWA1  = '290. FACILITY FINAL REPLICATE WT 1'
   F2FWA2  = '291. FACILITY FINAL REPLICATE WT 2'
   F2FWA3  = '292. FACILITY FINAL REPLICATE WT 3'
   F2FWA4  = '293. FACILITY FINAL REPLICATE WT 4'
   F2FWA5  = '294. FACILITY FINAL REPLICATE WT 5'
   F2FWA6  = '295. FACILITY FINAL REPLICATE WT 6'
   F2FWA7  = '296. FACILITY FINAL REPLICATE WT 7'
   F2FWA8  = '297. FACILITY FINAL REPLICATE WT 8'
   F2FWA9  = '298. FACILITY FINAL REPLICATE WT 9'
   F2FWA10 = '299. FACILITY FINAL REPLICATE WT 10'
   F2FWA11 = '300. FACILITY FINAL REPLICATE WT 11'
   F2FWA12 = '301. FACILITY FINAL REPLICATE WT 12'
   F2FWA13 = '302. FACILITY FINAL REPLICATE WT 13'
   F2FWA14 = '303. FACILITY FINAL REPLICATE WT 14'
   F2FWA15 = '304. FACILITY FINAL REPLICATE WT 15'
   F2FWA16 = '305. FACILITY FINAL REPLICATE WT 16'
   F2FWA17 = '306. FACILITY FINAL REPLICATE WT 17'
   F2FWA18 = '307. FACILITY FINAL REPLICATE WT 18'
   F2FWA19 = '308. FACILITY FINAL REPLICATE WT 19'
   F2FWA20 = '309. FACILITY FINAL REPLICATE WT 20'
   F2FWA21 = '310. FACILITY FINAL REPLICATE WT 21'
   F2FWA22 = '311. FACILITY FINAL REPLICATE WT 22'
   F2FWA23 = '312. FACILITY FINAL REPLICATE WT 23'
   F2FWA24 = '313. FACILITY FINAL REPLICATE WT 24'
   F2FWA25 = '314. FACILITY FINAL REPLICATE WT 25'
   F2FWA26 = '315. FACILITY FINAL REPLICATE WT 26'
   F2FWA27 = '316. FACILITY FINAL REPLICATE WT 27'
   F2FWA28 = '317. FACILITY FINAL REPLICATE WT 28'
   F2FWA29 = '318. FACILITY FINAL REPLICATE WT 29'
   F2FWA30 = '319. FACILITY FINAL REPLICATE WT 30'
   F2FWA31 = '320. FACILITY FINAL REPLICATE WT 31'
   F2FWA32 = '321. FACILITY FINAL REPLICATE WT 32'
   F2FWA33 = '322. FACILITY FINAL REPLICATE WT 33'
   F2FWA34 = '323. FACILITY FINAL REPLICATE WT 34'
   F2FWA35 = '324. FACILITY FINAL REPLICATE WT 35'
   F2FWA36 = '325. FACILITY FINAL REPLICATE WT 36'
   F2FWA37 = '326. FACILITY FINAL REPLICATE WT 37'
   F2FWA38 = '327. FACILITY FINAL REPLICATE WT 38'
   F2FWA39 = '328. FACILITY FINAL REPLICATE WT 39'
   F2FWA40 = '329. FACILITY FINAL REPLICATE WT 40'
   F2FWA41 = '330. FACILITY FINAL REPLICATE WT 41'
   F2FWA42 = '331. FACILITY FINAL REPLICATE WT 42'
   F2FWA43 = '332. FACILITY FINAL REPLICATE WT 43'
   F2FWA44 = '333. FACILITY FINAL REPLICATE WT 44'
   F2FWA45 = '334. FACILITY FINAL REPLICATE WT 45'
   F2FWA46 = '335. FACILITY FINAL REPLICATE WT 46'
   F2FWA47 = '336. FACILITY FINAL REPLICATE WT 47'
   F2FWA48 = '337. FACILITY FINAL REPLICATE WT 48'
   F2FWA49 = '338. FACILITY FINAL REPLICATE WT 49'
   F2FWA50 = '339. FACILITY FINAL REPLICATE WT 50'
   F2FWA51 = '340. FACILITY FINAL REPLICATE WT 51'
   F2FWA52 = '341. FACILITY FINAL REPLICATE WT 52'
   F2FWA53 = '342. FACILITY FINAL REPLICATE WT 53'
   F2FWA54 = '343. FACILITY FINAL REPLICATE WT 54'
   F2FWA55 = '344. FACILITY FINAL REPLICATE WT 55'
   F2FWA56 = '345. FACILITY FINAL REPLICATE WT 56'
   F2FWA57 = '346. FACILITY FINAL REPLICATE WT 57'
   F2FWA58 = '347. FACILITY FINAL REPLICATE WT 58'
   F2FWA59 = '348. FACILITY FINAL REPLICATE WT 59'
   F2FWA60 = '349. FACILITY FINAL REPLICATE WT 60'
   F2FWA61 = '350. FACILITY FINAL REPLICATE WT 61'
   F2FWA62 = '351. FACILITY FINAL REPLICATE WT 62'
   F2FWA63 = '352. FACILITY FINAL REPLICATE WT 63'
   F2FWA64 = '353. FACILITY FINAL REPLICATE WT 64'
   F2FWA65 = '354. FACILITY FINAL REPLICATE WT 65'
   F2FWA66 = '355. FACILITY FINAL REPLICATE WT 66'
   F2FWA67 = '356. FACILITY FINAL REPLICATE WT 67'
   F2FWA68 = '357. FACILITY FINAL REPLICATE WT 68'
   F2FWA69 = '358. FACILITY FINAL REPLICATE WT 69'
   F2FWA70 = '359. FACILITY FINAL REPLICATE WT 70'
   F2FWA71 = '360. FACILITY FINAL REPLICATE WT 71'
   F2FWA72 = '361. FACILITY FINAL REPLICATE WT 72'
   F2FWA73 = '362. FACILITY FINAL REPLICATE WT 73'
   F2FWA74 = '363. FACILITY FINAL REPLICATE WT 74'
   F2FWA75 = '364. FACILITY FINAL REPLICATE WT 75'
   F2FWA76 = '365. FACILITY FINAL REPLICATE WT 76'
   F2FWA77 = '366. FACILITY FINAL REPLICATE WT 77'
   F2FWA78 = '367. FACILITY FINAL REPLICATE WT 78'
   CLWGT1  = '368. CLIENT FINAL REPLICATE WT 1'
   CLWGT2  = '369. CLIENT FINAL REPLICATE WT 2'
   CLWGT3  = '370. CLIENT FINAL REPLICATE WT 3'
   CLWGT4  = '371. CLIENT FINAL REPLICATE WT 4'
   CLWGT5  = '372. CLIENT FINAL REPLICATE WT 5'
   CLWGT6  = '373. CLIENT FINAL REPLICATE WT 6'
   CLWGT7  = '374. CLIENT FINAL REPLICATE WT 7'
   CLWGT8  = '375. CLIENT FINAL REPLICATE WT 8'
   CLWGT9  = '376. CLIENT FINAL REPLICATE WT 9'
   CLWGT10 = '377. CLIENT FINAL REPLICATE WT 10'
   CLWGT11 = '378. CLIENT FINAL REPLICATE WT 11'
   CLWGT12 = '379. CLIENT FINAL REPLICATE WT 12'
   CLWGT13 = '380. CLIENT FINAL REPLICATE WT 13'
   CLWGT14 = '381. CLIENT FINAL REPLICATE WT 14'
   CLWGT15 = '382. CLIENT FINAL REPLICATE WT 15'
   CLWGT16 = '383. CLIENT FINAL REPLICATE WT 16'
   CLWGT17 = '384. CLIENT FINAL REPLICATE WT 17'
   CLWGT18 = '385. CLIENT FINAL REPLICATE WT 18'
   CLWGT19 = '386. CLIENT FINAL REPLICATE WT 19'
   CLWGT20 = '387. CLIENT FINAL REPLICATE WT 20'
   CLWGT21 = '388. CLIENT FINAL REPLICATE WT 21'
   CLWGT22 = '389. CLIENT FINAL REPLICATE WT 22'
   CLWGT23 = '390. CLIENT FINAL REPLICATE WT 23'
   CLWGT24 = '391. CLIENT FINAL REPLICATE WT 24'
   CLWGT25 = '392. CLIENT FINAL REPLICATE WT 25'
   CLWGT26 = '393. CLIENT FINAL REPLICATE WT 26'
   CLWGT27 = '394. CLIENT FINAL REPLICATE WT 27'
   CLWGT28 = '395. CLIENT FINAL REPLICATE WT 28'
   CLWGT29 = '396. CLIENT FINAL REPLICATE WT 29'
   CLWGT30 = '397. CLIENT FINAL REPLICATE WT 30'
   CLWGT31 = '398. CLIENT FINAL REPLICATE WT 31'
   CLWGT32 = '399. CLIENT FINAL REPLICATE WT 32'
   CLWGT33 = '400. CLIENT FINAL REPLICATE WT 33'
   CLWGT34 = '401. CLIENT FINAL REPLICATE WT 34'
   CLWGT35 = '402. CLIENT FINAL REPLICATE WT 35'
   CLWGT36 = '403. CLIENT FINAL REPLICATE WT 36'
   CLWGT37 = '404. CLIENT FINAL REPLICATE WT 37'
   CLWGT38 = '405. CLIENT FINAL REPLICATE WT 38'
   CLWGT39 = '406. CLIENT FINAL REPLICATE WT 39'
   CLWGT40 = '407. CLIENT FINAL REPLICATE WT 40'
   CLWGT41 = '408. CLIENT FINAL REPLICATE WT 41'
   CLWGT42 = '409. CLIENT FINAL REPLICATE WT 42'
   CLWGT43 = '410. CLIENT FINAL REPLICATE WT 43'
   CLWGT44 = '411. CLIENT FINAL REPLICATE WT 44'
   CLWGT45 = '412. CLIENT FINAL REPLICATE WT 45'
   CLWGT46 = '413. CLIENT FINAL REPLICATE WT 46'
   CLWGT47 = '414. CLIENT FINAL REPLICATE WT 47'
   CLWGT48 = '415. CLIENT FINAL REPLICATE WT 48'
   CLWGT49 = '416. CLIENT FINAL REPLICATE WT 49'
   CLWGT50 = '417. CLIENT FINAL REPLICATE WT 50'
   CLWGT51 = '418. CLIENT FINAL REPLICATE WT 51'
   CLWGT52 = '419. CLIENT FINAL REPLICATE WT 52'
   CLWGT53 = '420. CLIENT FINAL REPLICATE WT 53'
   CLWGT54 = '421. CLIENT FINAL REPLICATE WT 54'
   CLWGT55 = '422. CLIENT FINAL REPLICATE WT 55'
   CLWGT56 = '423. CLIENT FINAL REPLICATE WT 56'
   CLWGT57 = '424. CLIENT FINAL REPLICATE WT 57'
   CLWGT58 = '425. CLIENT FINAL REPLICATE WT 58'
   CLWGT59 = '426. CLIENT FINAL REPLICATE WT 59'
   CLWGT60 = '427. CLIENT FINAL REPLICATE WT 60'
   CLWGT61 = '428. CLIENT FINAL REPLICATE WT 61'
   CLWGT62 = '429. CLIENT FINAL REPLICATE WT 62'
   CLWGT63 = '430. CLIENT FINAL REPLICATE WT 63'
   CLWGT64 = '431. CLIENT FINAL REPLICATE WT 64'
   CLWGT65 = '432. CLIENT FINAL REPLICATE WT 65'
   CLWGT66 = '433. CLIENT FINAL REPLICATE WT 66'
   CLWGT67 = '434. CLIENT FINAL REPLICATE WT 67'
   CLWGT68 = '435. CLIENT FINAL REPLICATE WT 68'
   CLWGT69 = '436. CLIENT FINAL REPLICATE WT 69'
   CLWGT70 = '437. CLIENT FINAL REPLICATE WT 70'
   CLWGT71 = '438. CLIENT FINAL REPLICATE WT 71'
   CLWGT72 = '439. CLIENT FINAL REPLICATE WT 72'
   CLWGT73 = '440. CLIENT FINAL REPLICATE WT 73'
   CLWGT74 = '441. CLIENT FINAL REPLICATE WT 74'
   CLWGT75 = '442. CLIENT FINAL REPLICATE WT 75'
   CLWGT76 = '443. CLIENT FINAL REPLICATE WT 76'
   CLWGT77 = '444. CLIENT FINAL REPLICATE WT 77'
   CLWGT78 = '445. CLIENT FINAL REPLICATE WT 78'
   PPWGT1  = '446. PREVALENCE FINAL REPLICATE WT 1'
   PPWGT2  = '447. PREVALENCE FINAL REPLICATE WT 2'
   PPWGT3  = '448. PREVALENCE FINAL REPLICATE WT 3'
   PPWGT4  = '449. PREVALENCE FINAL REPLICATE WT 4'
   PPWGT5  = '450. PREVALENCE FINAL REPLICATE WT 5'
   PPWGT6  = '451. PREVALENCE FINAL REPLICATE WT 6'
   PPWGT7  = '452. PREVALENCE FINAL REPLICATE WT 7'
   PPWGT8  = '453. PREVALENCE FINAL REPLICATE WT 8'
   PPWGT9  = '454. PREVALENCE FINAL REPLICATE WT 9'
   PPWGT10 = '455. PREVALENCE FINAL REPLICATE WT 10'
   PPWGT11 = '456. PREVALENCE FINAL REPLICATE WT 11'
   PPWGT12 = '457. PREVALENCE FINAL REPLICATE WT 12'
   PPWGT13 = '458. PREVALENCE FINAL REPLICATE WT 13'
   PPWGT14 = '459. PREVALENCE FINAL REPLICATE WT 14'
   PPWGT15 = '460. PREVALENCE FINAL REPLICATE WT 15'
   PPWGT16 = '461. PREVALENCE FINAL REPLICATE WT 16'
   PPWGT17 = '462. PREVALENCE FINAL REPLICATE WT 17'
   PPWGT18 = '463. PREVALENCE FINAL REPLICATE WT 18'
   PPWGT19 = '464. PREVALENCE FINAL REPLICATE WT 19'
   PPWGT20 = '465. PREVALENCE FINAL REPLICATE WT 20'
   PPWGT21 = '466. PREVALENCE FINAL REPLICATE WT 21'
   PPWGT22 = '467. PREVALENCE FINAL REPLICATE WT 22'
   PPWGT23 = '468. PREVALENCE FINAL REPLICATE WT 23'
   PPWGT24 = '469. PREVALENCE FINAL REPLICATE WT 24'
   PPWGT25 = '470. PREVALENCE FINAL REPLICATE WT 25'
   PPWGT26 = '471. PREVALENCE FINAL REPLICATE WT 26'
   PPWGT27 = '472. PREVALENCE FINAL REPLICATE WT 27'
   PPWGT28 = '473. PREVALENCE FINAL REPLICATE WT 28'
   PPWGT29 = '474. PREVALENCE FINAL REPLICATE WT 29'
   PPWGT30 = '475. PREVALENCE FINAL REPLICATE WT 30'
   PPWGT31 = '476. PREVALENCE FINAL REPLICATE WT 31'
   PPWGT32 = '477. PREVALENCE FINAL REPLICATE WT 32'
   PPWGT33 = '478. PREVALENCE FINAL REPLICATE WT 33'
   PPWGT34 = '479. PREVALENCE FINAL REPLICATE WT 34'
   PPWGT35 = '480. PREVALENCE FINAL REPLICATE WT 35'
   PPWGT36 = '481. PREVALENCE FINAL REPLICATE WT 36'
   PPWGT37 = '482. PREVALENCE FINAL REPLICATE WT 37'
   PPWGT38 = '483. PREVALENCE FINAL REPLICATE WT 38'
   PPWGT39 = '484. PREVALENCE FINAL REPLICATE WT 39'
   PPWGT40 = '485. PREVALENCE FINAL REPLICATE WT 40'
   PPWGT41 = '486. PREVALENCE FINAL REPLICATE WT 41'
   PPWGT42 = '487. PREVALENCE FINAL REPLICATE WT 42'
   PPWGT43 = '488. PREVALENCE FINAL REPLICATE WT 43'
   PPWGT44 = '489. PREVALENCE FINAL REPLICATE WT 44'
   PPWGT45 = '490. PREVALENCE FINAL REPLICATE WT 45'
   PPWGT46 = '491. PREVALENCE FINAL REPLICATE WT 46'
   PPWGT47 = '492. PREVALENCE FINAL REPLICATE WT 47'
   PPWGT48 = '493. PREVALENCE FINAL REPLICATE WT 48'
   PPWGT49 = '494. PREVALENCE FINAL REPLICATE WT 49'
   PPWGT50 = '495. PREVALENCE FINAL REPLICATE WT 50'
   PPWGT51 = '496. PREVALENCE FINAL REPLICATE WT 51'
   PPWGT52 = '497. PREVALENCE FINAL REPLICATE WT 52'
   PPWGT53 = '498. PREVALENCE FINAL REPLICATE WT 53'
   PPWGT54 = '499. PREVALENCE FINAL REPLICATE WT 54'
   PPWGT55 = '500. PREVALENCE FINAL REPLICATE WT 55'
   PPWGT56 = '501. PREVALENCE FINAL REPLICATE WT 56'
   PPWGT57 = '502. PREVALENCE FINAL REPLICATE WT 57'
   PPWGT58 = '503. PREVALENCE FINAL REPLICATE WT 58'
   PPWGT59 = '504. PREVALENCE FINAL REPLICATE WT 59'
   PPWGT60 = '505. PREVALENCE FINAL REPLICATE WT 60'
   PPWGT61 = '506. PREVALENCE FINAL REPLICATE WT 61'
   PPWGT62 = '507. PREVALENCE FINAL REPLICATE WT 62'
   PPWGT63 = '508. PREVALENCE FINAL REPLICATE WT 63'
   PPWGT64 = '509. PREVALENCE FINAL REPLICATE WT 64'
   PPWGT65 = '510. PREVALENCE FINAL REPLICATE WT 65'
   PPWGT66 = '511. PREVALENCE FINAL REPLICATE WT 66'
   PPWGT67 = '512. PREVALENCE FINAL REPLICATE WT 67'
   PPWGT68 = '513. PREVALENCE FINAL REPLICATE WT 68'
   PPWGT69 = '514. PREVALENCE FINAL REPLICATE WT 69'
   PPWGT70 = '515. PREVALENCE FINAL REPLICATE WT 70'
   PPWGT71 = '516. PREVALENCE FINAL REPLICATE WT 71'
   PPWGT72 = '517. PREVALENCE FINAL REPLICATE WT 72'
   PPWGT73 = '518. PREVALENCE FINAL REPLICATE WT 73'
   PPWGT74 = '519. PREVALENCE FINAL REPLICATE WT 74'
   PPWGT75 = '520. PREVALENCE FINAL REPLICATE WT 75'
   PPWGT76 = '521. PREVALENCE FINAL REPLICATE WT 76'
   PPWGT77 = '522. PREVALENCE FINAL REPLICATE WT 77'
   PPWGT78 = '523. PREVALENCE FINAL REPLICATE WT 78'
   VST_PSU = '524. PHASE II VARIANCE STRATA'
   VUN_PSU = '525. PHASE II VARIANCE UNIT'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (OWNSHIP = -98 OR OWNSHIP = -99) THEN OWNSHIP = .;
   IF (STUDY = -98 OR STUDY = -99) THEN STUDY = .;
   IF (NQ3 = -98 OR NQ3 = -99) THEN NQ3 = .;
   IF (SQ3 = -98 OR SQ3 = -99) THEN SQ3 = .;
   IF (OADMIT = -98 OR OADMIT = -99) THEN OADMIT = .;
   IF (NQA = -98 OR NQA = -99) THEN NQA = .;
   IF (SQA = -98 OR SQA = -99) THEN SQA = .;
   IF (BIG_N = -98 OR BIG_N = -99) THEN BIG_N = .;
   IF (BIG_N2 = -98 OR BIG_N2 = -99) THEN BIG_N2 = .;
   IF (NQD = -98 OR NQD = -99) THEN NQD = .;
   IF (NQD2 = -98 OR NQD2 = -99) THEN NQD2 = .;
   IF (SQD = -98 OR SQD = -99) THEN SQD = .;
   IF (NQL = -98.00 OR NQL = -99.00) THEN NQL = .;
   IF (SQL = -98 OR SQL = -99) THEN SQL = .;
   IF (NQB = -98 OR NQB = -99) THEN NQB = .;
   IF (SQB = -98 OR SQB = -99) THEN SQB = .;
   IF (NQ55 = -98 OR NQ55 = -99) THEN NQ55 = .;
   IF (SQ55 = -98 OR SQ55 = -99) THEN SQ55 = .;
   IF (SQ52 = -98 OR SQ52 = -99) THEN SQ52 = .;
   IF (NQI = -98.00 OR NQI = -99.00) THEN NQI = .;
   IF (SQI = -98 OR SQI = -99) THEN SQI = .;
   IF (NQG1 = -98.0 OR NQG1 = -99.0) THEN NQG1 = .;
   IF (SQG1 = -98 OR SQG1 = -99) THEN SQG1 = .;
   IF (NQG2 = -98.0 OR NQG2 = -99.0) THEN NQG2 = .;
   IF (SQG2 = -98 OR SQG2 = -99) THEN SQG2 = .;
   IF (NQG3 = -98.0 OR NQG3 = -99.0) THEN NQG3 = .;
   IF (SQG3 = -98 OR SQG3 = -99) THEN SQG3 = .;
   IF (NQG4 = -98.0 OR NQG4 = -99.0) THEN NQG4 = .;
   IF (SQG4 = -98 OR SQG4 = -99) THEN SQG4 = .;
   IF (NQG5 = -98.00 OR NQG5 = -99.00) THEN NQG5 = .;
   IF (SQG5 <= -1) THEN SQG5 = .;
   IF (NQGS = -98.00 OR NQGS = -99.00) THEN NQGS = .;
   IF (SQGS <= -1) THEN SQGS = .;
   IF (NGRPHRS = -98.00 OR NGRPHRS = -99.00) THEN NGRPHRS = .;
   IF (SGRPHRS = -98 OR SGRPHRS = -99) THEN SGRPHRS = .;
   IF (NQ47A1 = -98 OR NQ47A1 = -99) THEN NQ47A1 = .;
   IF (SQ47A1 = -98 OR SQ47A1 = -99) THEN SQ47A1 = .;
   IF (NQ47B1 = -98 OR NQ47B1 = -99) THEN NQ47B1 = .;
   IF (SQ47B1 = -98 OR SQ47B1 = -99) THEN SQ47B1 = .;
   IF (NQ47C1 = -98 OR NQ47C1 = -99) THEN NQ47C1 = .;
   IF (SQ47C1 = -98 OR SQ47C1 = -99) THEN SQ47C1 = .;
   IF (NQ47D1 = -98 OR NQ47D1 = -99) THEN NQ47D1 = .;
   IF (SQ47D1 = -98 OR SQ47D1 = -99) THEN SQ47D1 = .;
   IF (NQ47E1 = -98.0 OR NQ47E1 = -99.0) THEN NQ47E1 = .;
   IF (SQ47E1 = -98 OR SQ47E1 = -99) THEN SQ47E1 = .;
   IF (NQ47F1 = -98 OR NQ47F1 = -99) THEN NQ47F1 = .;
   IF (SQ47F1 = -98 OR SQ47F1 = -99) THEN SQ47F1 = .;
   IF (NQ47G1 = -98 OR NQ47G1 = -99) THEN NQ47G1 = .;
   IF (SQ47G1 = -98 OR SQ47G1 = -99) THEN SQ47G1 = .;
   IF (NQ47H1 = -98.0 OR NQ47H1 = -99.0) THEN NQ47H1 = .;
   IF (SQ47H1 = -98 OR SQ47H1 = -99) THEN SQ47H1 = .;
   IF (NQ49A = -98.00 OR NQ49A = -99.00) THEN NQ49A = .;
   IF (SQ49A = -98 OR SQ49A = -99) THEN SQ49A = .;
   IF (NQ49B = -98.00 OR NQ49B = -99.00) THEN NQ49B = .;
   IF (SQ49B = -98 OR SQ49B = -99) THEN SQ49B = .;
   IF (NQ49C = -98.00 OR NQ49C = -99.00) THEN NQ49C = .;
   IF (SQ49C = -98 OR SQ49C = -99) THEN SQ49C = .;
   IF (NQ49D = -98.00 OR NQ49D = -99.00) THEN NQ49D = .;
   IF (SQ49D = -98 OR SQ49D = -99) THEN SQ49D = .;
   IF (NQ49E = -98.00 OR NQ49E = -99.00) THEN NQ49E = .;
   IF (SQ49E = -98 OR SQ49E = -99) THEN SQ49E = .;
   IF (NQ49F = -98.00 OR NQ49F = -99.00) THEN NQ49F = .;
   IF (SQ49F = -98 OR SQ49F = -99) THEN SQ49F = .;
   IF (NQ49G = -98.00 OR NQ49G = -99.00) THEN NQ49G = .;
   IF (SQ49G = -98 OR SQ49G = -99) THEN SQ49G = .;
   IF (NQ49H = -98.00 OR NQ49H = -99.00) THEN NQ49H = .;
   IF (SQ49H = -98 OR SQ49H = -99) THEN SQ49H = .;
   IF (NQ47A4 = -98.0 OR NQ47A4 = -99.0) THEN NQ47A4 = .;
   IF (SQ47A4 = -98 OR SQ47A4 = -99) THEN SQ47A4 = .;
   IF (NQ47B4 = -98.0 OR NQ47B4 = -99.0) THEN NQ47B4 = .;
   IF (SQ47B4 = -98 OR SQ47B4 = -99) THEN SQ47B4 = .;
   IF (NQ47C4 = -98.0 OR NQ47C4 = -99.0) THEN NQ47C4 = .;
   IF (SQ47C4 = -98 OR SQ47C4 = -99) THEN SQ47C4 = .;
   IF (NQ47D4 = -98.0 OR NQ47D4 = -99.0) THEN NQ47D4 = .;
   IF (SQ47D4 = -98 OR SQ47D4 = -99) THEN SQ47D4 = .;
   IF (NQ47E4 = -98.00 OR NQ47E4 = -99.00) THEN NQ47E4 = .;
   IF (SQ47E4 = -98 OR SQ47E4 = -99) THEN SQ47E4 = .;
   IF (NQ47F4 = -98.00 OR NQ47F4 = -99.00) THEN NQ47F4 = .;
   IF (SQ47F4 = -98 OR SQ47F4 = -99) THEN SQ47F4 = .;
   IF (NQ47G4 = -98.00 OR NQ47G4 = -99.00) THEN NQ47G4 = .;
   IF (SQ47G4 = -98 OR SQ47G4 = -99) THEN SQ47G4 = .;
   IF (NQ47H4 = -98.00 OR NQ47H4 = -99.00) THEN NQ47H4 = .;
   IF (SQ47H4 = -98 OR SQ47H4 = -99) THEN SQ47H4 = .;
   IF (NQ47A23 = -98 OR NQ47A23 = -99) THEN NQ47A23 = .;
   IF (SQ47A23 <= -1) THEN SQ47A23 = .;
   IF (NQ47B23 = -98 OR NQ47B23 = -99) THEN NQ47B23 = .;
   IF (SQ47B23 = -98 OR SQ47B23 = -99) THEN SQ47B23 = .;
   IF (NQ47C23 = -98 OR NQ47C23 = -99) THEN NQ47C23 = .;
   IF (SQ47C23 = -98 OR SQ47C23 = -99) THEN SQ47C23 = .;
   IF (NQ47D23 = -98 OR NQ47D23 = -99) THEN NQ47D23 = .;
   IF (SQ47D23 = -98 OR SQ47D23 = -99) THEN SQ47D23 = .;
   IF (NQ47E23 = -98 OR NQ47E23 = -99) THEN NQ47E23 = .;
   IF (SQ47E23 = -98 OR SQ47E23 = -99) THEN SQ47E23 = .;
   IF (NQ47F23 = -98 OR NQ47F23 = -99) THEN NQ47F23 = .;
   IF (SQ47F23 = -98 OR SQ47F23 = -99) THEN SQ47F23 = .;
   IF (NQ47G23 = -98 OR NQ47G23 = -99) THEN NQ47G23 = .;
   IF (SQ47G23 = -98 OR SQ47G23 = -99) THEN SQ47G23 = .;
   IF (NQ47H23 = -98 OR NQ47H23 = -99) THEN NQ47H23 = .;
   IF (SQ47H23 = -98 OR SQ47H23 = -99) THEN SQ47H23 = .;
   IF (NQ49PA = -98.00 OR NQ49PA = -99.00) THEN NQ49PA = .;
   IF (SQ49PA = -98 OR SQ49PA = -99) THEN SQ49PA = .;
   IF (NQ49PB = -98.00 OR NQ49PB = -99.00) THEN NQ49PB = .;
   IF (SQ49PB = -98 OR SQ49PB = -99) THEN SQ49PB = .;
   IF (NQ49PC = -98.00 OR NQ49PC = -99.00) THEN NQ49PC = .;
   IF (SQ49PC = -98 OR SQ49PC = -99) THEN SQ49PC = .;
   IF (NQ49PD = -98.00 OR NQ49PD = -99.00) THEN NQ49PD = .;
   IF (SQ49PD = -98 OR SQ49PD = -99) THEN SQ49PD = .;
   IF (NQ49PE = -98.00 OR NQ49PE = -99.00) THEN NQ49PE = .;
   IF (SQ49PE = -98 OR SQ49PE = -99) THEN SQ49PE = .;
   IF (NQ49PF = -98.00 OR NQ49PF = -99.00) THEN NQ49PF = .;
   IF (SQ49PF = -98 OR SQ49PF = -99) THEN SQ49PF = .;
   IF (NQ49PG = -98.00 OR NQ49PG = -99.00) THEN NQ49PG = .;
   IF (SQ49PG = -98 OR SQ49PG = -99) THEN SQ49PG = .;
   IF (NQ49PH = -98.00 OR NQ49PH = -99.00) THEN NQ49PH = .;
   IF (SQ49PH = -98 OR SQ49PH = -99) THEN SQ49PH = .;
   IF (NQ47A4R = -98.00 OR NQ47A4R = -99.00) THEN NQ47A4R = .;
   IF (SQ47A4R = -98 OR SQ47A4R = -99) THEN SQ47A4R = .;
   IF (NQ47B4R = -98.00 OR NQ47B4R = -99.00) THEN NQ47B4R = .;
   IF (SQ47B4R = -98 OR SQ47B4R = -99) THEN SQ47B4R = .;
   IF (NQ47C4R = -98.00 OR NQ47C4R = -99.00) THEN NQ47C4R = .;
   IF (SQ47C4R = -98 OR SQ47C4R = -99) THEN SQ47C4R = .;
   IF (NQ47D4R = -98.00 OR NQ47D4R = -99.00) THEN NQ47D4R = .;
   IF (SQ47D4R = -98 OR SQ47D4R = -99) THEN SQ47D4R = .;
   IF (NQ47E4R = -98.00 OR NQ47E4R = -99.00) THEN NQ47E4R = .;
   IF (SQ47E4R = -98 OR SQ47E4R = -99) THEN SQ47E4R = .;
   IF (NQ47F4R = -98.00 OR NQ47F4R = -99.00) THEN NQ47F4R = .;
   IF (SQ47F4R = -98 OR SQ47F4R = -99) THEN SQ47F4R = .;
   IF (NQ47G4R = -98.00 OR NQ47G4R = -99.00) THEN NQ47G4R = .;
   IF (SQ47G4R = -98 OR SQ47G4R = -99) THEN SQ47G4R = .;
   IF (NQ47H4R = -98.00 OR NQ47H4R = -99.00) THEN NQ47H4R = .;
   IF (SQ47H4R = -98 OR SQ47H4R = -99) THEN SQ47H4R = .;
   IF (NQ50 = -98.0000 OR NQ50 = -99.0000) THEN NQ50 = .;
   IF (SQ50 = -98 OR SQ50 = -99) THEN SQ50 = .;
   IF (SNB12 = -98 OR SNB12 = -99) THEN SNB12 = .;
   IF (NC21 = -98 OR NC21 = -99) THEN NC21 = .;
   IF (SNC21 = -98 OR SNC21 = -99) THEN SNC21 = .;
   IF (NC22 = -98 OR NC22 = -99) THEN NC22 = .;
   IF (SNC22 = -98 OR SNC22 = -99) THEN SNC22 = .;
   IF (NC3 = -98.00 OR NC3 = -99.00) THEN NC3 = .;
   IF (SC3 = -98 OR SC3 = -99) THEN SC3 = .;
   IF (ND14 = -98 OR ND14 = -99) THEN ND14 = .;
   IF (SD14 = -98 OR SD14 = -99) THEN SD14 = .;
   IF (SD7 = -98 OR SD7 = -99) THEN SD7 = .;
   IF (ND15A = -98.0 OR ND15A = -99.0) THEN ND15A = .;
   IF (SD15A = -98 OR SD15A = -99) THEN SD15A = .;
   IF (ND15AP = -98.000 OR ND15AP = -99.000) THEN ND15AP = .;
   IF (SD15AP = -98 OR SD15AP = -99) THEN SD15AP = .;
   IF (ND15A_D = -98 OR ND15A_D = -99) THEN ND15A_D = .;
   IF (ND15A_P = -98.0000 OR ND15A_P = -99.0000) THEN ND15A_P = .;
   IF (ND15B = -98 OR ND15B = -99) THEN ND15B = .;
   IF (SD15B = -98 OR SD15B = -99) THEN SD15B = .;
   IF (ND15BP = -98.000 OR ND15BP = -99.000) THEN ND15BP = .;
   IF (SD15BP = -98 OR SD15BP = -99) THEN SD15BP = .;
   IF (ND15B_D = -98.0 OR ND15B_D = -99.0) THEN ND15B_D = .;
   IF (ND15B_P = -98.000 OR ND15B_P = -99.000) THEN ND15B_P = .;
   IF (ND15C = -98.0 OR ND15C = -99.0) THEN ND15C = .;
   IF (SD15C = -98 OR SD15C = -99) THEN SD15C = .;
   IF (ND15CP = -98.0000 OR ND15CP = -99.0000) THEN ND15CP = .;
   IF (SD15CP = -98 OR SD15CP = -99) THEN SD15CP = .;
   IF (ND15C_D = -98.0 OR ND15C_D = -99.0) THEN ND15C_D = .;
   IF (ND15C_P = -98.0000 OR ND15C_P = -99.0000) THEN ND15C_P = .;
   IF (ND15D = -98 OR ND15D = -99) THEN ND15D = .;
   IF (SD15D = -98 OR SD15D = -99) THEN SD15D = .;
   IF (ND15DP = -98.0000 OR ND15DP = -99.0000) THEN ND15DP = .;
   IF (SD15DP = -98 OR SD15DP = -99) THEN SD15DP = .;
   IF (ND15D_D = -98.0 OR ND15D_D = -99.0) THEN ND15D_D = .;
   IF (ND15D_P = -98.0000 OR ND15D_P = -99.0000) THEN ND15D_P = .;
   IF (V1K17 = -98.0000 OR V1K17 = -99.0000) THEN V1K17 = .;
   IF (V1K20 = -98.0000 OR V1K20 = -99.0000) THEN V1K20 = .;
   IF (V1K23 = -98.0000 OR V1K23 = -99.0000) THEN V1K23 = .;
   IF (N1C26 = -98 OR N1C26 = -99) THEN N1C26 = .;
   IF (N1G26 = -98.0 OR N1G26 = -99.0) THEN N1G26 = .;
   IF (V1K26 = -98.0000 OR V1K26 = -99.0000) THEN V1K26 = .;
   IF (N1C27 = -98 OR N1C27 = -99) THEN N1C27 = .;
   IF (N1G27 = -98 OR N1G27 = -99) THEN N1G27 = .;
   IF (V1K27 = -98.0000 OR V1K27 = -99.0000) THEN V1K27 = .;
   IF (N1C33 = -98.0000 OR N1C33 = -99.0000) THEN N1C33 = .;
   IF (N1G33 = -98.0000 OR N1G33 = -99.0000) THEN N1G33 = .;
   IF (V1K33 = -98.0000 OR V1K33 = -99.0000) THEN V1K33 = .;
   IF (N1C34 = -98.0000 OR N1C34 = -99.0000) THEN N1C34 = .;
   IF (N1G34 = -98.0000 OR N1G34 = -99.0000) THEN N1G34 = .;
   IF (V1K34 = -98.0000 OR V1K34 = -99.0000) THEN V1K34 = .;
   IF (N1C35 = -98.0000 OR N1C35 = -99.0000) THEN N1C35 = .;
   IF (N1G35 = -98.00 OR N1G35 = -99.00) THEN N1G35 = .;
   IF (V1K35 = -98.00 OR V1K35 = -99.00) THEN V1K35 = .;
   IF (V1C37 = -98.0000 OR V1C37 = -99.0000) THEN V1C37 = .;
   IF (V1C38 = -98.0000 OR V1C38 = -99.0000) THEN V1C38 = .;
   IF (V2F9 = -98.0000 OR V2F9 = -99.0000) THEN V2F9 = .;
   IF (V2F12 = -98.0000 OR V2F12 = -99.0000) THEN V2F12 = .;
   IF (U2B22 = -98.0 OR U2B22 = -99.0) THEN U2B22 = .;
   IF (U2D22 = -98 OR U2D22 = -99) THEN U2D22 = .;
   IF (V2F22 = -98.0000 OR V2F22 = -99.0000) THEN V2F22 = .;
   IF (U2B23 = -98.0000 OR U2B23 = -99.0000) THEN U2B23 = .;
   IF (U2D23 = -98.0000 OR U2D23 = -99.0000) THEN U2D23 = .;
   IF (U2B25 = -98.0 OR U2B25 = -99.0) THEN U2B25 = .;
   IF (U2D25 = -98 OR U2D25 = -99) THEN U2D25 = .;
   IF (V2F25 = -98.0000 OR V2F25 = -99.0000) THEN V2F25 = .;
   IF (U2B26 = -98.0000 OR U2B26 = -99.0000) THEN U2B26 = .;
   IF (U2D26 = -98.0000 OR U2D26 = -99.0000) THEN U2D26 = .;
   IF (U2B28 = -98.0 OR U2B28 = -99.0) THEN U2B28 = .;
   IF (U2B29 = -98.0000 OR U2B29 = -99.0000) THEN U2B29 = .;
   IF (U2B30 = -98.0000 OR U2B30 = -99.0000) THEN U2B30 = .;
   IF (U2B31 = -98.00 OR U2B31 = -99.00) THEN U2B31 = .;
   IF (N3N12 = -98.0 OR N3N12 = -99.0) THEN N3N12 = .;
   IF (N3N13 = -98.0 OR N3N13 = -99.0) THEN N3N13 = .;
   IF (N3N14 = -98.0 OR N3N14 = -99.0) THEN N3N14 = .;
   IF (N3N15 = -98.0 OR N3N15 = -99.0) THEN N3N15 = .;
   IF (N3N16 = -98.0 OR N3N16 = -99.0) THEN N3N16 = .;
   IF (N3N17 = -98.0 OR N3N17 = -99.0) THEN N3N17 = .;
   IF (N3N18 = -98.0 OR N3N18 = -99.0) THEN N3N18 = .;
   IF (N3N19 = -98.0 OR N3N19 = -99.0) THEN N3N19 = .;
   IF (N3N23 = -98.0 OR N3N23 = -99.0) THEN N3N23 = .;
   IF (N3N24 = -98.0 OR N3N24 = -99.0) THEN N3N24 = .;
   IF (N3N25 = -98.0 OR N3N25 = -99.0) THEN N3N25 = .;
   IF (N3N26 = -98.0 OR N3N26 = -99.0) THEN N3N26 = .;
   IF (N3N27 = -98.0 OR N3N27 = -99.0) THEN N3N27 = .;
   IF (N3N28 = -98.0 OR N3N28 = -99.0) THEN N3N28 = .;
   IF (N3N29 = -98.0 OR N3N29 = -99.0) THEN N3N29 = .;
   IF (N3N30 = -98.0 OR N3N30 = -99.0) THEN N3N30 = .;
   IF (N3B32 = -98.00 OR N3B32 = -99.00) THEN N3B32 = .;
   IF (N3N32 = -98.0 OR N3N32 = -99.0) THEN N3N32 = .;
   IF (N3N33 = -98.0 OR N3N33 = -99.0) THEN N3N33 = .;
   IF (N3N34 = -98.0 OR N3N34 = -99.0) THEN N3N34 = .;
   IF (P3N38 = -98.0000 OR P3N38 = -99.0000) THEN P3N38 = .;
   IF (N3J40 = -98.0 OR N3J40 = -99.0) THEN N3J40 = .;
   IF (P3N40 = -98.0000 OR P3N40 = -99.0000) THEN P3N40 = .;
   IF (N3J42 = -98.0 OR N3J42 = -99.0) THEN N3J42 = .;
   IF (P3N42 = -98.0000 OR P3N42 = -99.0000) THEN P3N42 = .;
   IF (N3J44 = -98.0 OR N3J44 = -99.0) THEN N3J44 = .;
   IF (P3N44 = -98.0000 OR P3N44 = -99.0000) THEN P3N44 = .;
   IF (N3J46 = -98.0 OR N3J46 = -99.0) THEN N3J46 = .;
   IF (N4N7 = -98.0 OR N4N7 = -99.0) THEN N4N7 = .;
   IF (P3N46 = -98.0000 OR P3N46 = -99.0000) THEN P3N46 = .;
   IF (N4B8 = -98.0000 OR N4B8 = -99.0000) THEN N4B8 = .;
   IF (N4F8 = -98.0 OR N4F8 = -99.0) THEN N4F8 = .;
   IF (N4B9 = -98.0000 OR N4B9 = -99.0000) THEN N4B9 = .;
   IF (N4F9 = -98.0 OR N4F9 = -99.0) THEN N4F9 = .;
   IF (N4J9 = -98.0000 OR N4J9 = -99.0000) THEN N4J9 = .;
   IF (N4J12 = -98.0000 OR N4J12 = -99.0000) THEN N4J12 = .;
   IF (N4N12 = -98.0 OR N4N12 = -99.0) THEN N4N12 = .;
   IF (N4N17 = -98.00 OR N4N17 = -99.00) THEN N4N17 = .;
   IF (N4N18 = -98.00 OR N4N18 = -99.00) THEN N4N18 = .;
   IF (N4N19 = -98.00 OR N4N19 = -99.00) THEN N4N19 = .;
   IF (N4N20 = -98.000 OR N4N20 = -99.000) THEN N4N20 = .;
   IF (N4N21 = -98.0000 OR N4N21 = -99.0000) THEN N4N21 = .;
   IF (N4N22 = -98.0000 OR N4N22 = -99.0000) THEN N4N22 = .;
   IF (N4F24 = -98.0000 OR N4F24 = -99.0000) THEN N4F24 = .;
   IF (N4J24 = -98.0000 OR N4J24 = -99.0000) THEN N4J24 = .;
   IF (N4B27 = -98.0000 OR N4B27 = -99.0000) THEN N4B27 = .;
   IF (N4N27 = -98.0 OR N4N27 = -99.0) THEN N4N27 = .;
   IF (N4N30 = -98.0 OR N4N30 = -99.0) THEN N4N30 = .;
   IF (N4N31 = -98.0000 OR N4N31 = -99.0000) THEN N4N31 = .;
   IF (N4N32 = -98.0000 OR N4N32 = -99.0000) THEN N4N32 = .;
   IF (N4J36 = -98.0 OR N4J36 = -99.0) THEN N4J36 = .;
   IF (N4N36 = -98.0 OR N4N36 = -99.0) THEN N4N36 = .;
   IF (N4N38 = -98.0 OR N4N38 = -99.0) THEN N4N38 = .;
   IF (N4N42 = -98.0 OR N4N42 = -99.0) THEN N4N42 = .;
   IF (V5F28 = -98.0000 OR V5F28 = -99.0000) THEN V5F28 = .;
   IF (V5F30 = -98.0000 OR V5F30 = -99.0000) THEN V5F30 = .;
   IF (V5F32 = -98.0000 OR V5F32 = -99.0000) THEN V5F32 = .;
   IF (N5D36 = -98.0000 OR N5D36 = -99.0000) THEN N5D36 = .;
   IF (V5F36 = -98.0000 OR V5F36 = -99.0000) THEN V5F36 = .;
   IF (ABVISIT = -98.0000 OR ABVISIT = -99.0000) THEN ABVISIT = .;
   IF (TRT_DUR = -98 OR TRT_DUR = -99) THEN TRT_DUR = .;
   IF (ABALOS = -98.0 OR ABALOS = -99.0) THEN ABALOS = .;
   IF (ABALOSSD = -98.0 OR ABALOSSD = -99.0) THEN ABALOSSD = .;
   IF (N = -98 OR N = -99) THEN N = .;
   IF (SE = -98.0 OR SE = -99.0) THEN SE = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT FACTYPE factype. OWNSHIP ownship. MULTIPLE multiple.
         STUDY study. NQ3 nq3fffff. SQ3 sq3fffff.
         OADMIT oadmit. NQA nqa. SQA sqa.
         BIG_N big_n. BIG_N2 big_n2ff. NQD nqd.
         NQD2 nqd2ffff. SQD sqd. NQL nql.
         SQL sql. NQB nqb. SQB sqb.
         NQ55 nq55ffff. SQ55 sq55ffff. SQ52 sq52ffff.
         NQI nqi. SQI sqi. NQG1 nqg1ffff.
         SQG1 sqg1ffff. NQG2 nqg2ffff. SQG2 sqg2ffff.
         NQG3 nqg3ffff. SQG3 sqg3ffff. NQG4 nqg4ffff.
         SQG4 sqg4ffff. NQG5 nqg5ffff. SQG5 sqg5ffff.
         NQGS nqgs. SQGS sqgs. NGRPHRS ngrphrs.
         SGRPHRS sgrphrs. NQ47A1 nq47a1ff. SQ47A1 sq47a1ff.
         NQ47B1 nq47b1ff. SQ47B1 sq47b1ff. NQ47C1 nq47c1ff.
         SQ47C1 sq47c1ff. NQ47D1 nq47d1ff. SQ47D1 sq47d1ff.
         NQ47E1 nq47e1ff. SQ47E1 sq47e1ff. NQ47F1 nq47f1ff.
         SQ47F1 sq47f1ff. NQ47G1 nq47g1ff. SQ47G1 sq47g1ff.
         NQ47H1 nq47h1ff. SQ47H1 sq47h1ff. NQ49A nq49a.
         SQ49A sq49a. NQ49B nq49b. SQ49B sq49b.
         NQ49C nq49c. SQ49C sq49c. NQ49D nq49d.
         SQ49D sq49d. NQ49E nq49e. SQ49E sq49e.
         NQ49F nq49f. SQ49F sq49f. NQ49G nq49g.
         SQ49G sq49g. NQ49H nq49h. SQ49H sq49h.
         NQ47A4 nq47a4ff. SQ47A4 sq47a4ff. NQ47B4 nq47b4ff.
         SQ47B4 sq47b4ff. NQ47C4 nq47c4ff. SQ47C4 sq47c4ff.
         NQ47D4 nq47d4ff. SQ47D4 sq47d4ff. NQ47E4 nq47e4ff.
         SQ47E4 sq47e4ff. NQ47F4 nq47f4ff. SQ47F4 sq47f4ff.
         NQ47G4 nq47g4ff. SQ47G4 sq47g4ff. NQ47H4 nq47h4ff.
         SQ47H4 sq47h4ff. NQ47A23 nq47a23f. SQ47A23 sq47a23f.
         NQ47B23 nq47b23f. SQ47B23 sq47b23f. NQ47C23 nq47c23f.
         SQ47C23 sq47c23f. NQ47D23 nq47d23f. SQ47D23 sq47d23f.
         NQ47E23 nq47e23f. SQ47E23 sq47e23f. NQ47F23 nq47f23f.
         SQ47F23 sq47f23f. NQ47G23 nq47g23f. SQ47G23 sq47g23f.
         NQ47H23 nq47h23f. SQ47H23 sq47h23f. NQ49PA nq49pa.
         SQ49PA sq49pa. NQ49PB nq49pb. SQ49PB sq49pb.
         NQ49PC nq49pc. SQ49PC sq49pc. NQ49PD nq49pd.
         SQ49PD sq49pd. NQ49PE nq49pe. SQ49PE sq49pe.
         NQ49PF nq49pf. SQ49PF sq49pf. NQ49PG nq49pg.
         SQ49PG sq49pg. NQ49PH nq49ph. SQ49PH sq49ph.
         NQ47A4R nq47a4r. SQ47A4R sq47a4r. NQ47B4R nq47b4r.
         SQ47B4R sq47b4r. NQ47C4R nq47c4r. SQ47C4R sq47c4r.
         NQ47D4R nq47d4r. SQ47D4R sq47d4r. NQ47E4R nq47e4r.
         SQ47E4R sq47e4r. NQ47F4R nq47f4r. SQ47F4R sq47f4r.
         NQ47G4R nq47g4r. SQ47G4R sq47g4r. NQ47H4R nq47h4r.
         SQ47H4R sq47h4r. NQ50 nq50ffff. SQ50 sq50ffff.
         SNB12 snb12fff. NC21 nc21ffff. SNC21 snc21fff.
         NC22 nc22ffff. SNC22 snc22fff. NC3 nc3fffff.
         SC3 sc3fffff. ND14 nd14ffff. SD14 sd14ffff.
         SD7 sd7fffff. ND15A nd15a. SD15A sd15a.
         ND15AP nd15ap. SD15AP sd15ap. ND15A_D nd15a_d.
         ND15A_P nd15a_p. ND15B nd15b. SD15B sd15b.
         ND15BP nd15bp. SD15BP sd15bp. ND15B_D nd15b_d.
         ND15B_P nd15b_p. ND15C nd15c. SD15C sd15c.
         ND15CP nd15cp. SD15CP sd15cp. ND15C_D nd15c_d.
         ND15C_P nd15c_p. ND15D nd15d. SD15D sd15d.
         ND15DP nd15dp. SD15DP sd15dp. ND15D_D nd15d_d.
         ND15D_P nd15d_p. V1K17 v1k17fff. V1K20 v1k20fff.
         V1K23 v1k23fff. N1C26 n1c26fff. N1G26 n1g26fff.
         V1K26 v1k26fff. N1C27 n1c27fff. N1G27 n1g27fff.
         V1K27 v1k27fff. N1C33 n1c33fff. N1G33 n1g33fff.
         V1K33 v1k33fff. N1C34 n1c34fff. N1G34 n1g34fff.
         V1K34 v1k34fff. N1C35 n1c35fff. N1G35 n1g35fff.
         V1K35 v1k35fff. V1C37 v1c37fff. V1C38 v1c38fff.
         V2F9 v2f9ffff. V2F12 v2f12fff. U2B22 u2b22fff.
         U2D22 u2d22fff. V2F22 v2f22fff. U2B23 u2b23fff.
         U2D23 u2d23fff. U2B25 u2b25fff. U2D25 u2d25fff.
         V2F25 v2f25fff. U2B26 u2b26fff. U2D26 u2d26fff.
         U2B28 u2b28fff. U2B29 u2b29fff. U2B30 u2b30fff.
         U2B31 u2b31fff. N3N12 n3n12fff. N3N13 n3n13fff.
         N3N14 n3n14fff. N3N15 n3n15fff. N3N16 n3n16fff.
         N3N17 n3n17fff. N3N18 n3n18fff. N3N19 n3n19fff.
         N3N23 n3n23fff. N3N24 n3n24fff. N3N25 n3n25fff.
         N3N26 n3n26fff. N3N27 n3n27fff. N3N28 n3n28fff.
         N3N29 n3n29fff. N3N30 n3n30fff. N3B32 n3b32fff.
         N3N32 n3n32fff. N3N33 n3n33fff. N3N34 n3n34fff.
         P3N38 p3n38fff. N3J40 n3j40fff. P3N40 p3n40fff.
         N3J42 n3j42fff. P3N42 p3n42fff. N3J44 n3j44fff.
         P3N44 p3n44fff. N3J46 n3j46fff. N4N7 n4n7ffff.
         P3N46 p3n46fff. N4B8 n4b8ffff. N4F8 n4f8ffff.
         N4B9 n4b9ffff. N4F9 n4f9ffff. N4J9 n4j9ffff.
         N4J12 n4j12fff. N4N12 n4n12fff. N4N17 n4n17fff.
         N4N18 n4n18fff. N4N19 n4n19fff. N4N20 n4n20fff.
         N4N21 n4n21fff. N4N22 n4n22fff. N4F24 n4f24fff.
         N4J24 n4j24fff. N4B27 n4b27fff. N4N27 n4n27fff.
         N4N30 n4n30fff. N4N31 n4n31fff. N4N32 n4n32fff.
         N4J36 n4j36fff. N4N36 n4n36fff. N4N38 n4n38fff.
         N4N42 n4n42fff. V5F28 v5f28fff. V5F30 v5f30fff.
         V5F32 v5f32fff. N5D36 n5d36fff. V5F36 v5f36fff.
         ABVISIT abvisit. TRT_DUR trt_dur. ABALOS abalos.
         ABALOSSD abalossd. N n. SE se.
          ;
*/

RUN ;
